@@ -157,6 +157,23 @@ Synonim for `title`.
 =end
 
 
+	# Render to an HTML fragment (returns a REXML document tree)
+	def to_html_tree
+		div = Element.new 'div'
+			div.attributes['class'] = 'maruku_wrapper_div'
+				children_to_html.each do |e|
+						  div << e
+				end
+
+				# render footnotes
+				if @doc.footnotes_order.size > 0
+						  div << render_footnotes
+				end
+
+		 doc = Document.new(nil,{:respect_whitespace =>:all})
+		 doc << div
+	end
+
 =begin maruku_doc
 Attribute: css
 Scope: document
@@ -166,11 +183,12 @@ Summary: Activates CSS stylesheets for HTML.
 `css` should be a space-separated list of urls.
 
 Example:
-	
+
 	CSS: style.css math.css
 
 =end
 
+
 	# Render to a complete HTML document (returns a REXML document tree)
 	def to_html_document_tree
 		doc = Document.new(nil,{:respect_whitespace =>:all})
@@ -465,7 +483,7 @@ by Maruku, to have the same results in both HTML and LaTeX.
 	end
 
 	def source2html(source)
-		source = source.gsub(/&/,'&amp;')
+#		source = source.gsub(/&/,'&amp;')
 		source = Text.normalize(source)
 		source = source.gsub(/\&apos;/,'&#39;') # IE bug
 		source = source.gsub(/'/,'&#39;') # IE bug
@@ -591,7 +609,7 @@ of the form `#ff00ff`.
 		code = Element.new 'code', pre
 		s = source
 		
-		s  = s.gsub(/&/,'&amp;')
+#		s  = s.gsub(/&/,'&amp;')
 		s = Text.normalize(s)
 		s  = s.gsub(/\&apos;/,'&#39;') # IE bug
 		s  = s.gsub(/'/,'&#39;') # IE bug
@@ -892,7 +910,7 @@ If true, raw HTML is discarded from the output.
 #			Entity.new(entity_name)
 			Text.new('&#%d;' % [entity_name],  false, nil, true)
 		else
-			Text.new('&%s;' % [entity_name])
+			Text.new('&%s;' % [entity_name],  false, nil, true)
 		end
 	end
 
